{% extends "users/base.html" %}
{% load crispy_forms_tags %}
{% block content %}
    <div class="content-section" style="color: white; margin-left: 30px;">
        <form method="POST">
            {% csrf_token %}
            <fieldset class="form-group" style="border-width: 10px; font-size: 17px; padding-left: 30px;">
                <legend class="border-bottom mb-4" style="font-size: 40px;">Reset Password</legend>
                {{ form|crispy }}
                <div class="form-group" style="margin-top: 10px;">
                    <button class="primary-btn" type="submit">Reset Password</button>
                </div>
            </fieldset>
        </form>
    </div>
{% endblock content %}