{% extends "users/base.html" %}
{% load crispy_forms_tags %}
{% block content %}
<!--<link rel="stylesheet" href="https://maxcdn.bootstrapcdn.com/bootstrap/3.4.1/css/bootstrap.min.css" >-->
    <div class="content-section" style="color: white; margin-left: 30px;">
        <form method="POST">
            {% csrf_token %}
            <fieldset class="form-group" style="border-width: 10px; font-size: 17px; padding-left: 30px;">
                <legend class="border-bottom mb-4" style="font-size: 40px; ">Register</legend>
                {{ form|crispy }}
                <div class="form-group" style="margin-bottom: 10px; margin-top: 10px; ">
                    <button class="primary-btn" type="submit">Sign Up</button>
                </div>
            </fieldset>
            
        </form>
        <div class="border-top pt-3" style="margin-bottom: 10px; margin-top: 10px; font-size: 17px;">
            <small class="text-muted">
                Already Have An Account? <a class ="ml-2" href={% url 'login' %}>Sign In</a>
            </small>
        </div>
    </div>
{% endblock content %}
