{% extends "users/base.html" %}
{% block content %}
    <div class="alert alert-info">
        Your password has been reset.
    </div>
    <a href = "{% url 'login' %}">Sign In Here</a>
{% endblock content %}