{% extends "users/base.html" %}
{% block content %}
    <div style="display: flex; align-items: flex-start">
        <h6 style="margin-left: 5rem; color: white;">You have been logged out.</h6>
        <div class="content-section" style="display: flex; align-items: center">
            <small class="text-muted">
                <a style="width: 25rem; margin: 2rem;" href={% url 'login' %}>Click Here to Log In Again</a>
            </small>
        </div>
    </div>
{% endblock content %}